EXPORTS
	??4CBitset@ContentAccess@@QAEAAV01@ABV01@@Z @ 1 NONAME ; public: class ContentAccess::CBitset & __thiscall ContentAccess::CBitset::operator=(class ContentAccess::CBitset const &)
	??8CBitset@ContentAccess@@QBEHABV01@@Z @ 2 NONAME ; public: int __thiscall ContentAccess::CBitset::operator==(class ContentAccess::CBitset const &)const 
	?ExternalizeL@CBitset@ContentAccess@@QBEXAAVRWriteStream@@@Z @ 3 NONAME ; public: void __thiscall ContentAccess::CBitset::ExternalizeL(class RWriteStream &)const 
	?InternalizeL@CBitset@ContentAccess@@QAEXAAVRReadStream@@@Z @ 4 NONAME ; public: void __thiscall ContentAccess::CBitset::InternalizeL(class RReadStream &)
	?Invert@CBitset@ContentAccess@@QAEXXZ @ 5 NONAME ; public: void __thiscall ContentAccess::CBitset::Invert(void)
	?IsSet@CBitset@ContentAccess@@QBEHH@Z @ 6 NONAME ; public: int __thiscall ContentAccess::CBitset::IsSet(int)const 
	?IsSetList@CBitset@ContentAccess@@QBAHHZZ @ 7 NONAME ; public: int __cdecl ContentAccess::CBitset::IsSetList(int,...)const 
	?NewL@CBitset@ContentAccess@@SAPAV12@ABV12@@Z @ 8 NONAME ; public: static class ContentAccess::CBitset * __cdecl ContentAccess::CBitset::NewL(class ContentAccess::CBitset const &)
	?NewL@CBitset@ContentAccess@@SAPAV12@H@Z @ 9 NONAME ; public: static class ContentAccess::CBitset * __cdecl ContentAccess::CBitset::NewL(int)
	?NewLC@CBitset@ContentAccess@@SAPAV12@ABV12@@Z @ 10 NONAME ; public: static class ContentAccess::CBitset * __cdecl ContentAccess::CBitset::NewLC(class ContentAccess::CBitset const &)
	?NewLC@CBitset@ContentAccess@@SAPAV12@H@Z @ 11 NONAME ; public: static class ContentAccess::CBitset * __cdecl ContentAccess::CBitset::NewLC(int)
	?Reset@CBitset@ContentAccess@@QAEXXZ @ 12 NONAME ; public: void __thiscall ContentAccess::CBitset::Reset(void)
	?Set@CBitset@ContentAccess@@QAEXH@Z @ 13 NONAME ; public: void __thiscall ContentAccess::CBitset::Set(int)
	?SetAll@CBitset@ContentAccess@@QAEXXZ @ 14 NONAME ; public: void __thiscall ContentAccess::CBitset::SetAll(void)
	?SetListL@CBitset@ContentAccess@@QAAXHZZ @ 15 NONAME ; public: void __cdecl ContentAccess::CBitset::SetListL(int,...)
	?Unset@CBitset@ContentAccess@@QAEXH@Z @ 16 NONAME ; public: void __thiscall ContentAccess::CBitset::Unset(int)
	?MaxBits@CBitset@ContentAccess@@QBEHXZ @ 17 NONAME ; public: int __thiscall ContentAccess::CBitset::MaxBits(void)const 
	??1CCafMimeHeader@ContentAccess@@UAE@XZ @ 18 NONAME ; public: virtual __thiscall ContentAccess::CCafMimeHeader::~CCafMimeHeader(void)
	?AddNonStandardMimeL@CCafMimeHeader@ContentAccess@@QAEXABVTDesC8@@0@Z @ 19 NONAME ; public: void __thiscall ContentAccess::CCafMimeHeader::AddNonStandardMimeL(class TDesC8 const &,class TDesC8 const &)
	?ExternalizeL@CCafMimeHeader@ContentAccess@@QBEXAAVRWriteStream@@@Z @ 20 NONAME ; public: void __thiscall ContentAccess::CCafMimeHeader::ExternalizeL(class RWriteStream &)const 
	?InternalizeL@CCafMimeHeader@ContentAccess@@QAEXAAVRReadStream@@@Z @ 21 NONAME ; public: void __thiscall ContentAccess::CCafMimeHeader::InternalizeL(class RReadStream &)
	?NewL@CCafMimeHeader@ContentAccess@@SAPAV12@ABVTDesC8@@@Z @ 22 NONAME ; public: static class ContentAccess::CCafMimeHeader * __cdecl ContentAccess::CCafMimeHeader::NewL(class TDesC8 const &)
	?NonStandardMimeCount@CCafMimeHeader@ContentAccess@@QBEHXZ @ 23 NONAME ; public: int __thiscall ContentAccess::CCafMimeHeader::NonStandardMimeCount(void)const 
	?NonStandardMimeData@CCafMimeHeader@ContentAccess@@QBE?AVTPtrC8@@H@Z @ 24 NONAME ; public: class TPtrC8  __thiscall ContentAccess::CCafMimeHeader::NonStandardMimeData(int)const 
	?NonStandardMimeField@CCafMimeHeader@ContentAccess@@QBE?AVTPtrC8@@H@Z @ 25 NONAME ; public: class TPtrC8  __thiscall ContentAccess::CCafMimeHeader::NonStandardMimeField(int)const 
	?SetStandardMimeDataL@CCafMimeHeader@ContentAccess@@QAEXABW4TMimeFields@2@ABVTDesC8@@@Z @ 26 NONAME ; public: void __thiscall ContentAccess::CCafMimeHeader::SetStandardMimeDataL(enum ContentAccess::TMimeFields const &,class TDesC8 const &)
	?StandardMimeData@CCafMimeHeader@ContentAccess@@QBE?AVTPtrC8@@ABW4TMimeFields@2@@Z @ 27 NONAME ; public: class TPtrC8  __thiscall ContentAccess::CCafMimeHeader::StandardMimeData(enum ContentAccess::TMimeFields const &)const 
	??0RAttributeSet@ContentAccess@@QAE@XZ @ 28 NONAME ; ContentAccess::RAttributeSet::RAttributeSet(void)
	??0RStringAttributeSet@ContentAccess@@QAE@XZ @ 29 NONAME ; ContentAccess::RStringAttributeSet::RStringAttributeSet(void)
	??0TVirtualPathPtr@ContentAccess@@QAE@ABV01@@Z @ 30 NONAME ; ContentAccess::TVirtualPathPtr::TVirtualPathPtr(class ContentAccess::TVirtualPathPtr const &)
	??0TVirtualPathPtr@ContentAccess@@QAE@ABVTDesC16@@0@Z @ 31 NONAME ; ContentAccess::TVirtualPathPtr::TVirtualPathPtr(class TDesC16 const &, class TDesC16 const &)
	??0TVirtualPathPtr@ContentAccess@@QAE@ABVTDesC16@@@Z @ 32 NONAME ; ContentAccess::TVirtualPathPtr::TVirtualPathPtr(class TDesC16 const &)
	??4TVirtualPathPtr@ContentAccess@@QAEAAV01@ABV01@@Z @ 33 NONAME ; class ContentAccess::TVirtualPathPtr & ContentAccess::TVirtualPathPtr::operator=(class ContentAccess::TVirtualPathPtr const &)
	??4TVirtualPathPtr@ContentAccess@@QAEAAV01@ABVTDesC16@@@Z @ 34 NONAME ; class ContentAccess::TVirtualPathPtr & ContentAccess::TVirtualPathPtr::operator=(class TDesC16 const &)
	??ACDirStreamable@ContentAccess@@QBEABVTEntry@@H@Z @ 35 NONAME ; class TEntry const & ContentAccess::CDirStreamable::operator[](int) const
	??ACMetaDataArray@ContentAccess@@QBEABVCMetaData@1@H@Z @ 36 NONAME ; class ContentAccess::CMetaData const & ContentAccess::CMetaDataArray::operator[](int) const
	??ARAttributeSet@ContentAccess@@QBEHH@Z @ 37 NONAME ; int ContentAccess::RAttributeSet::operator[](int) const
	??ARStringAttributeSet@ContentAccess@@QBEHH@Z @ 38 NONAME ; int ContentAccess::RStringAttributeSet::operator[](int) const
	?AddL@CDirStreamable@ContentAccess@@QAEXABVTEntry@@@Z @ 39 NONAME ; void ContentAccess::CDirStreamable::AddL(class TEntry const &)
	?AddL@CMetaDataArray@ContentAccess@@QAEXABVTDesC16@@0@Z @ 40 NONAME ; void ContentAccess::CMetaDataArray::AddL(class TDesC16 const &, class TDesC16 const &)
	?AddL@CMetaDataArray@ContentAccess@@QAEXABVTDesC8@@0@Z @ 41 NONAME ; void ContentAccess::CMetaDataArray::AddL(class TDesC8 const &, class TDesC8 const &)
	?AddL@RAttributeSet@ContentAccess@@QAEXH@Z @ 42 NONAME ; void ContentAccess::RAttributeSet::AddL(int)
	?AddL@RStringAttributeSet@ContentAccess@@QAEXH@Z @ 43 NONAME ; void ContentAccess::RStringAttributeSet::AddL(int)
	?Close@RAttributeSet@ContentAccess@@QAEXXZ @ 44 NONAME ; void ContentAccess::RAttributeSet::Close(void)
	?Close@RStringAttributeSet@ContentAccess@@QAEXXZ @ 45 NONAME ; void ContentAccess::RStringAttributeSet::Close(void)
	?Count@CDirStreamable@ContentAccess@@QBEHXZ @ 46 NONAME ; int ContentAccess::CDirStreamable::Count(void) const
	?Count@CMetaDataArray@ContentAccess@@QBEHXZ @ 47 NONAME ; int ContentAccess::CMetaDataArray::Count(void) const
	?Count@RAttributeSet@ContentAccess@@QBEHXZ @ 48 NONAME ; int ContentAccess::RAttributeSet::Count(void) const
	?Count@RStringAttributeSet@ContentAccess@@QBEHXZ @ 49 NONAME ; int ContentAccess::RStringAttributeSet::Count(void) const
	?Data8@CMetaData@ContentAccess@@QBEABVTDesC8@@XZ @ 50 NONAME ; class TDesC8 const & ContentAccess::CMetaData::Data8(void) const
	?Data@CMetaData@ContentAccess@@QBEABVTDesC16@@XZ @ 51 NONAME ; class TDesC16 const & ContentAccess::CMetaData::Data(void) const
	?Description@CRightsInfo@ContentAccess@@QBEABVTDesC16@@XZ @ 52 NONAME ; class TDesC16 const & ContentAccess::CRightsInfo::Description(void) const
	?ExternalizeL@CDirStreamable@ContentAccess@@QBEXAAVRWriteStream@@@Z @ 53 NONAME ; void ContentAccess::CDirStreamable::ExternalizeL(class RWriteStream &) const
	?ExternalizeL@CEmbeddedObject@ContentAccess@@QBEXAAVRWriteStream@@@Z @ 54 NONAME ; void ContentAccess::CEmbeddedObject::ExternalizeL(class RWriteStream &) const
	?ExternalizeL@CMetaDataArray@ContentAccess@@QBEXAAVRWriteStream@@@Z @ 55 NONAME ; void ContentAccess::CMetaDataArray::ExternalizeL(class RWriteStream &) const
	?ExternalizeL@CRightsInfo@ContentAccess@@QBEXAAVRWriteStream@@@Z @ 56 NONAME ; void ContentAccess::CRightsInfo::ExternalizeL(class RWriteStream &) const
	?ExternalizeL@CVirtualPath@ContentAccess@@QBEXAAVRWriteStream@@@Z @ 57 NONAME ; void ContentAccess::CVirtualPath::ExternalizeL(class RWriteStream &) const
	?ExternalizeL@RAttributeSet@ContentAccess@@QBEXAAVRWriteStream@@@Z @ 58 NONAME ; void ContentAccess::RAttributeSet::ExternalizeL(class RWriteStream &) const
	?ExternalizeL@RStringAttributeSet@ContentAccess@@QBEXAAVRWriteStream@@@Z @ 59 NONAME ; void ContentAccess::RStringAttributeSet::ExternalizeL(class RWriteStream &) const
	?Field8@CMetaData@ContentAccess@@QBEABVTDesC8@@XZ @ 60 NONAME ; class TDesC8 const & ContentAccess::CMetaData::Field8(void) const
	?Field@CMetaData@ContentAccess@@QBEABVTDesC16@@XZ @ 61 NONAME ; class TDesC16 const & ContentAccess::CMetaData::Field(void) const
	?GetCombinedUriUniqueId@CVirtualPath@ContentAccess@@QAEABVTDesC16@@XZ @ 62 NONAME ; class TDesC16 const & ContentAccess::CVirtualPath::GetCombinedUriUniqueId(void)
	?GetValue@RAttributeSet@ContentAccess@@QBEHHAAH@Z @ 63 NONAME ; int ContentAccess::RAttributeSet::GetValue(int, int &) const
	?GetValue@RStringAttributeSet@ContentAccess@@QBEHHAAVTDes16@@@Z @ 64 NONAME ; int ContentAccess::RStringAttributeSet::GetValue(int, class TDes16 &) const
	?GetValueLength@RStringAttributeSet@ContentAccess@@QBEHH@Z @ 65 NONAME ; int ContentAccess::RStringAttributeSet::GetValueLength(int) const
	?InternalizeL@RAttributeSet@ContentAccess@@QAEXAAVRReadStream@@@Z @ 66 NONAME ; void ContentAccess::RAttributeSet::InternalizeL(class RReadStream &)
	?InternalizeL@RStringAttributeSet@ContentAccess@@QAEXAAVRReadStream@@@Z @ 67 NONAME ; void ContentAccess::RStringAttributeSet::InternalizeL(class RReadStream &)
	?MimeType@CEmbeddedObject@ContentAccess@@QBEABVTDesC8@@XZ @ 68 NONAME ; class TDesC8 const & ContentAccess::CEmbeddedObject::MimeType(void) const
	?Name@CEmbeddedObject@ContentAccess@@QBEABVTDesC16@@XZ @ 69 NONAME ; class TDesC16 const & ContentAccess::CEmbeddedObject::Name(void) const
	?NewL@CDirStreamable@ContentAccess@@SAPAV12@AAVCDir@@@Z @ 70 NONAME ; class ContentAccess::CDirStreamable * ContentAccess::CDirStreamable::NewL(class CDir &)
	?NewL@CDirStreamable@ContentAccess@@SAPAV12@VRReadStream@@@Z @ 71 NONAME ; class ContentAccess::CDirStreamable * ContentAccess::CDirStreamable::NewL(class RReadStream)
	?NewL@CDirStreamable@ContentAccess@@SAPAV12@XZ @ 72 NONAME ; class ContentAccess::CDirStreamable * ContentAccess::CDirStreamable::NewL(void)
	?NewL@CEmbeddedObject@ContentAccess@@SAPAV12@AAVRReadStream@@@Z @ 73 NONAME ; class ContentAccess::CEmbeddedObject * ContentAccess::CEmbeddedObject::NewL(class RReadStream &)
	?NewL@CEmbeddedObject@ContentAccess@@SAPAV12@ABVTDesC16@@0ABVTDesC8@@W4TEmbeddedType@2@@Z @ 74 NONAME ; class ContentAccess::CEmbeddedObject * ContentAccess::CEmbeddedObject::NewL(class TDesC16 const &, class TDesC16 const &, class TDesC8 const &, enum ContentAccess::TEmbeddedType)
	?NewL@CEmbeddedObject@ContentAccess@@SAPAV12@ABVTDesC16@@ABVTDesC8@@W4TEmbeddedType@2@@Z @ 75 NONAME ; class ContentAccess::CEmbeddedObject * ContentAccess::CEmbeddedObject::NewL(class TDesC16 const &, class TDesC8 const &, enum ContentAccess::TEmbeddedType)
	?NewL@CMetaDataArray@ContentAccess@@SAPAV12@AAVRReadStream@@@Z @ 76 NONAME ; class ContentAccess::CMetaDataArray * ContentAccess::CMetaDataArray::NewL(class RReadStream &)
	?NewL@CMetaDataArray@ContentAccess@@SAPAV12@XZ @ 77 NONAME ; class ContentAccess::CMetaDataArray * ContentAccess::CMetaDataArray::NewL(void)
	?NewL@CRightsInfo@ContentAccess@@SAPAV12@AAVRReadStream@@@Z @ 78 NONAME ; class ContentAccess::CRightsInfo * ContentAccess::CRightsInfo::NewL(class RReadStream &)
	?NewL@CRightsInfo@ContentAccess@@SAPAV12@ABVTDesC16@@0HW4TRightsStatus@2@@Z @ 79 NONAME ; class ContentAccess::CRightsInfo * ContentAccess::CRightsInfo::NewL(class TDesC16 const &, class TDesC16 const &, int, enum ContentAccess::TRightsStatus)
	?NewL@CVirtualPath@ContentAccess@@SAPAV12@AAVRReadStream@@@Z @ 80 NONAME ; class ContentAccess::CVirtualPath * ContentAccess::CVirtualPath::NewL(class RReadStream &)
	?NewL@CVirtualPath@ContentAccess@@SAPAV12@ABVTDesC16@@0@Z @ 81 NONAME ; class ContentAccess::CVirtualPath * ContentAccess::CVirtualPath::NewL(class TDesC16 const &, class TDesC16 const &)
	?NewL@CVirtualPath@ContentAccess@@SAPAV12@ABVTDesC16@@@Z @ 82 NONAME ; class ContentAccess::CVirtualPath * ContentAccess::CVirtualPath::NewL(class TDesC16 const &)
	?NewL@CVirtualPath@ContentAccess@@SAPAV12@ABVTVirtualPathPtr@2@@Z @ 83 NONAME ; class ContentAccess::CVirtualPath * ContentAccess::CVirtualPath::NewL(class ContentAccess::TVirtualPathPtr const &)
	?NewLC@CMetaDataArray@ContentAccess@@SAPAV12@XZ @ 84 NONAME ; class ContentAccess::CMetaDataArray * ContentAccess::CMetaDataArray::NewLC(void)
	?RightsStatus@CRightsInfo@ContentAccess@@QBE?AW4TRightsStatus@2@XZ @ 85 NONAME ; enum ContentAccess::TRightsStatus ContentAccess::CRightsInfo::RightsStatus(void) const
	?RightsType@CRightsInfo@ContentAccess@@QBEHXZ @ 86 NONAME ; int ContentAccess::CRightsInfo::RightsType(void) const
	?SearchL@CMetaDataArray@ContentAccess@@QBEABVTDesC16@@ABV3@H@Z @ 87 NONAME ; class TDesC16 const & ContentAccess::CMetaDataArray::SearchL(class TDesC16 const &, int) const
	?SearchL@CMetaDataArray@ContentAccess@@QBEABVTDesC8@@ABV3@H@Z @ 88 NONAME ; class TDesC8 const & ContentAccess::CMetaDataArray::SearchL(class TDesC8 const &, int) const
	?SetValue@RAttributeSet@ContentAccess@@QAEHHHH@Z @ 89 NONAME ; int ContentAccess::RAttributeSet::SetValue(int, int, int)
	?SetValue@RStringAttributeSet@ContentAccess@@QAEHHABVTDesC16@@H@Z @ 90 NONAME ; int ContentAccess::RStringAttributeSet::SetValue(int, class TDesC16 const &, int)
	?Sort@CDirStreamable@ContentAccess@@QAEHI@Z @ 91 NONAME ; int ContentAccess::CDirStreamable::Sort(unsigned int)
	?Type@CEmbeddedObject@ContentAccess@@QBE?AW4TEmbeddedType@2@XZ @ 92 NONAME ; enum ContentAccess::TEmbeddedType ContentAccess::CEmbeddedObject::Type(void) const
	?URI@CVirtualPath@ContentAccess@@QBEABVTDesC16@@XZ @ 93 NONAME ; class TDesC16 const & ContentAccess::CVirtualPath::URI(void) const
	?URI@TVirtualPathPtr@ContentAccess@@QBEABVTDesC16@@XZ @ 94 NONAME ; class TDesC16 const & ContentAccess::TVirtualPathPtr::URI(void) const
	?UniqueId@CEmbeddedObject@ContentAccess@@QBEABVTDesC16@@XZ @ 95 NONAME ; class TDesC16 const & ContentAccess::CEmbeddedObject::UniqueId(void) const
	?UniqueId@CRightsInfo@ContentAccess@@QBEABVTDesC16@@XZ @ 96 NONAME ; class TDesC16 const & ContentAccess::CRightsInfo::UniqueId(void) const
	?UniqueId@CVirtualPath@ContentAccess@@QBEABVTDesC16@@XZ @ 97 NONAME ; class TDesC16 const & ContentAccess::CVirtualPath::UniqueId(void) const
	?UniqueId@TVirtualPathPtr@ContentAccess@@QBEABVTDesC16@@XZ @ 98 NONAME ; class TDesC16 const & ContentAccess::TVirtualPathPtr::UniqueId(void) const
	?NewL@CCAFHelper@ContentAccess@@SAPAV12@XZ @ 99 NONAME ; class ContentAccess::CCAFHelper * ContentAccess::CCAFHelper::NewL(void)
	?NewLC@CCAFHelper@ContentAccess@@SAPAV12@XZ @ 100 NONAME ; class ContentAccess::CCAFHelper * ContentAccess::CCAFHelper::NewLC(void)
	??RCCAFHelper@ContentAccess@@QBEAAVMCAFHelperInterface@1@XZ @ 101 NONAME ; class ContentAccess::MCAFHelperInterface & ContentAccess::CCAFHelper::operator()(void) const

